## Docs
|Location|Url|
|:---:|:---:|
|China|[Docs](https://rhythmlian.cn/2020/02/14/QuickProject/)|
|Other|[Docs](https://rhythmicc.github.io/2020/02/14/QuickProject/)|

## Tab Completion

```shell
cp complete/<your language>/* /path/in/$fpath
```

then add `compinit` to the end of `.zshrc`


## Manual Install
```shell
git clone https://github.com/Rhythmicc/QuickProject.git
cd QuickProject
python setup.py install
```
